==> oggcodecs_src_0.63.7755.zip: oggdsf/src/lib/codecs/cmml/libCMMLTags/C_MetaTag.cpp <==
/*
   Copyright (C) 2003, 2004 Zentaro Kavanagh
   
   Copyright (C) 2003, 2004 Commonwealth Scientific and Industrial Research
   Organisation (CSIRO) Australia

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of CSIRO Australia nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#include "StdAfx.h"
#include ".\c_metatag.h"

C_MetaTag::C_MetaTag(void)
{
	mTagType = C_CMMLTag::eTagType::META;
}

C_MetaTag::~C_MetaTag(void)
{
}
//Accessors
string C_MetaTag::scheme() {
	return mScheme;
}

//Mutators
void C_MetaTag::setScheme(string inScheme) {
	mScheme = inScheme;
}

//Other

void C_MetaTag::privateClone(C_CMMLTag* outTag) {
	C_MappedTag::privateClone(outTag);
	C_MetaTag* locTag = reinterpret_cast<C_MetaTag*>(outTag);
	locTag->setScheme(mScheme);
}
C_MetaTag* C_MetaTag::clone() {
	C_MetaTag* retTag = new C_MetaTag;
	privateClone(retTag);
	return retTag;

}
C_CMMLTag* C_MetaTag::genericClone() {
	return clone();
}
C_MappedTag* C_MetaTag::mappedClone() {
	return clone();
}
string C_MetaTag::toString() {
	//QUERY ::: How are the internationalisation tags included
	string retStr = "<meta";
	retStr += " name=\"";
	retStr += mName;
	retStr += "\" content=\"";
	retStr += mContent;
	retStr += "\"";
	retStr += "/>\n";


	return retStr;
}

==> oggcodecs_src_0.68.8333.zip: oggdsf/src/lib/codecs/cmml/libCMMLTags/C_MetaTag.cpp <==
/*
   Copyright (C) 2003, 2004 Zentaro Kavanagh
   
   Copyright (C) 2003, 2004 Commonwealth Scientific and Industrial Research
   Organisation (CSIRO) Australia

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of CSIRO Australia nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#include "StdAfx.h"
#include ".\c_metatag.h"

C_MetaTag::C_MetaTag(void)
{
	mTagType = C_CMMLTag::eTagType::META;
}

C_MetaTag::~C_MetaTag(void)
{
}
//Accessors
wstring C_MetaTag::scheme() {
	return mScheme;
}

//Mutators
void C_MetaTag::setScheme(wstring inScheme) {
	mScheme = inScheme;
}

//Other

void C_MetaTag::privateClone(C_CMMLTag* outTag) {
	C_MappedTag::privateClone(outTag);
	C_MetaTag* locTag = reinterpret_cast<C_MetaTag*>(outTag);
	locTag->setScheme(mScheme);
}
C_MetaTag* C_MetaTag::clone() {
	C_MetaTag* retTag = new C_MetaTag;
	privateClone(retTag);
	return retTag;

}
C_CMMLTag* C_MetaTag::genericClone() {
	return clone();
}
C_MappedTag* C_MetaTag::mappedClone() {
	return clone();
}
wstring C_MetaTag::toString() {
	//QUERY ::: How are the internationalisation tags included
	wstring retStr = L"<meta";

	if (mId.size() != 0) {
		retStr += makeElement(L"id", mId);
	}

	retStr += makeLangElements();
	retStr += makeElement(L"name", mName);
	retStr += makeElement(L"content", mContent);

	if (mScheme != L"") {
		retStr += makeElement(L"scheme", mScheme);
	}

	retStr += L"/>\n";


	return retStr;
}
